#!/bin/bash
# Autor: Arturo Martín Romero - amartinromero@gmail.com - programa de software libre

## Comenzamos importando y definiendo las variables que usaremos posteriormente:
. /etc/default/vx-dga-variables/vx-dga-variables-general.conf
LOG="/tmp/salida-imponer-resolucion-${USER}.log"
COMANDO="xrandr | grep -v 'disconnected' | grep -v 'unknow' | grep 'connected'"

# Comprobamos el número de segundos de espera antes de imponer (primer parámetro de llamada)
ESPERA=0
if ! test -z "$1" ; then
        ESPERA="$1"
fi
echo "=> $(date) - Vamos a esperar ${ESPERA} sg. para imponer la resolución ..." | tee ${LOG}
CONTADOR=0
while test ${CONTADOR} -le ${ESPERA} ; do
        echo "=> Esperando ${CONTADOR} sg. ..." | tee -a ${LOG}
        CONTADOR="$(expr ${CONTADOR} + 1)"
        sleep 1
done

if test -f /usr/bin/migasfree-tags ; then
	ETIQUETAS="$(sudo migasfree-tags -g | tr -s '"' ' ')"
	echo "=> Las etiquetas Migasfree del equipo son: ${ETIQUETAS}" | tee -a ${LOG}
fi

# Comprobamos el segundo parámetro de llamada: resolución a imponer
RESOLUCION=""
if ! test -z "$2" ; then
	RESOLUCION="$2"
	echo "=> Se va a tratar de imponer la resolución: ${RESOLUCION} ..." | tee -a ${LOG}
else
	if ( echo "${ETIQUETAS}" | grep "TUBALCAIN.PCSAULA" &> /dev/null ) ; then
		RESOLUCION="1024x768"
		echo "=> Se va a tratar de imponer a TUBALCAIN.PCSAULA la resolución: ${RESOLUCION} ..." | tee -a ${LOG}
	fi
fi

SALIDAS=$(xrandr \
	| grep -v 'disconnected' | grep -v 'unknow' \
	| grep 'connected' | awk -F" " '{ print $1 }' | tr -s "\n" " ")
while test -z "${SALIDAS}" ; do
	sleep 1
	SALIDAS=$(xrandr \
		| grep -v 'disconnected' | grep -v 'unknow' \
		| grep 'connected' | awk -F" " '{ print $1 }' | tr -s "\n" " ")
done

echo "=> Las salidas a tratar de configurar son: \"${SALIDAS}\"" | tee -a ${LOG}

if ! test -z "${RESOLUCION}" ; then
	# Mediante la variable MODO nos aseguramos que la resolución deseada es posible imponer
	# Su valor, enc caso de éxito, coincidirá con la resolución deseada:
	# MODO="$(xrandr | grep "1024x768" | awk -F" " '{print $1}')"
	if test $(echo ${SALIDAS} | wc -w) -eq 1 ; then
		MODO="$(xrandr | grep -v disconnected | grep -v 'unknow' | grep -v connected \
			| grep "${RESOLUCION}" | head -1 | awk -F" " '{print $1}')"
		FRECUENCIA="$(xrandr | grep -v disconnected | grep -v 'unknow' | grep -v connected \
			| grep "${RESOLUCION}" | awk -F" " '{print $2}' | tr -s "*" " ")"
		echo "=> Modo de Salida a imponer en ${SALIDAS}: ${MODO} - ${FRECUENCIA}" | tee -a ${LOG}
		xrandr --output "$(echo ${SALIDAS} | cut -d" " -f1)" --mode "${MODO}" --rate "${FRECUENCIA}"
	fi
	if test $(echo ${SALIDAS} | wc -w) -eq 2 ; then
		# Líneas asociadas a las salidas conectadas:
		LINEAS=$(xrandr | grep -v disconnected | grep -v 'unknow' \
			| grep -n connected | cut -d":" -f1)
		LINEAOUTPUT1=$(echo ${LINEAS} | cut -d" " -f1)
		LINEAOUTPUT2=$(echo ${LINEAS} | cut -d" " -f2)

		echo "=> Información de la Salida 1 (linea ${LINEAOUTPUT1}):" | tee -a ${LOG}
		xrandr | grep -v disconnected | grep -v 'unknow' \
			| sed -n "$LINEAOUTPUT1,$(expr $LINEAOUTPUT2 - 1)p" | tee -a ${LOG}
		echo "=> Información de la Salida 2 (linea ${LINEAOUTPUT2}):" | tee -a ${LOG}
		xrandr | grep -v disconnected | grep -v 'unknow' \
			| sed -n "$LINEAOUTPUT2"',$p' | tee -a ${LOG}

		MODO1=$(xrandr | grep -v disconnected | grep -v 'unknow' \
			| sed -n "$LINEAOUTPUT1,$(expr $LINEAOUTPUT2 - 1)p" | grep -v connected \
			| grep "${RESOLUCION}" | head -1 | awk -F" " '{print $1}')
		FRECUENCIA1=$(xrandr | grep -v disconnected | grep -v 'unknow' \
			| sed -n "$LINEAOUTPUT1,$(expr $LINEAOUTPUT2 - 1)p" | grep -v connected \
			| grep "${RESOLUCION}" | head -1 | awk -F" " '{print $2}' | tr -s "*" " ")
		MODO2=$(xrandr | grep -v disconnected | grep -v 'unknow' \
			| sed -n "$LINEAOUTPUT2"',$p' | grep -v connected \
			| grep "${RESOLUCION}" | head -1 | awk -F" " '{print $1}')
		FRECUENCIA2=$(xrandr | grep -v disconnected | grep -v 'unknow' \
			| sed -n "$LINEAOUTPUT2"',$p' | grep -v connected \
			| grep "${RESOLUCION}" | head -1 | awk -F" " '{print $2}' | tr -s "*" " ")

		echo "=> Modos de Salida a imponer: ${MODO1} - ${FRECUENCIA1} y ${MODO2} - ${FRECUENCIA2}" | tee -a ${LOG}
		xrandr \
			--output "$(echo ${SALIDAS} | cut -d" " -f1)" --mode "${MODO1}" --rate "${FRECUENCIA1}" \
			--output "$(echo ${SALIDAS} | cut -d" " -f2)" --mode "${MODO2}" --rate "${FRECUENCIA2}"
	fi
	echo "=> Reiniciamos el Widget Conky del Escritorio ..." | tee -a ${LOG}
	/usr/bin/inicio-conky &> /dev/null
	xrandr | tee -a ${LOG}
fi
